@@ -1,6 +1,5 @@
 //! Prints "Hello, world" on the OpenOCD console
 
-#![deny(unsafe_code)]
 #![no_main]
 #![no_std]
 
@@ -20,11 +19,11 @@ fn main() -> ! {
 }
 
 #[exception]
-fn HardFault(ef: &ExceptionFrame) -> ! {
+unsafe fn HardFault(ef: &ExceptionFrame) -> ! {
     panic!("{:#?}", ef);
 }
 
 #[exception]
-fn DefaultHandler(irqn: i16) {
+unsafe fn DefaultHandler(irqn: i16) {
     panic!("Unhandled exception (IRQn = {})", irqn);
 }
