@@ -5,11 +5,13 @@
 //! # Reset & Clock Unit
 
 use crate::flash::WS;
+#[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
+use crate::pac::rcu::cfg0::USBDPSC_A;
 use crate::pac::{
     fmc::ws::WSCNT_A,
     rcu::{
         self,
-        cfg0::{ADCPSC_A, AHBPSC_A, APB1PSC_A, APB2PSC_A, PLLSEL_A, SCS_A, USBDPSC_A},
+        cfg0::{ADCPSC_A, AHBPSC_A, APB1PSC_A, APB2PSC_A, PLLSEL_A, SCS_A},
     },
     RCU,
 };
@@ -31,6 +33,7 @@ impl RcuExt for RCU {
             ahb: AHB { _0: () },
             apb1: APB1 { _0: () },
             apb2: APB2 { _0: () },
+            addapb1: ADDAPB1 { _0: () },
             cfgr: CFGR {
                 hxtal: None,
                 hclk: None,
@@ -60,6 +63,8 @@ pub struct Rcu {
     pub apb1: APB1,
     /// Advanced Peripheral Bus 2 (APB2) registers
     pub apb2: APB2,
+    /// Additional Advanced Peripheral Bus 1 (ADDAPB1) registers
+    pub addapb1: ADDAPB1,
     pub cfgr: CFGR,
     pub bkp: BKP,
 }
@@ -109,9 +114,7 @@ impl APB1 {
         // NOTE(unsafe) this proxy grants exclusive access to this register
         unsafe { &(*RCU::ptr()).apb1rst }
     }
-}
 
-impl APB1 {
     /// Set power interface clock (PWREN) bit in RCU_APB1ENR
     pub fn set_pwren(&mut self) {
         self.enr().modify(|_r, w| w.pmuen().enabled())
@@ -143,6 +146,33 @@ impl APB2 {
     }
 }
 
+/// Additional Advanced Peripheral Bus 1 (APB1) registers
+///
+/// Aquired through the `Rcu` registers:
+///
+/// ```rust
+/// let dp = pac::Peripherals::take().unwrap();
+/// let mut rcu = dp.RCU.constrain();
+/// function_that_uses_addapb1(&mut rcu.addapb1)
+/// ```
+pub struct ADDAPB1 {
+    _0: (),
+}
+
+impl ADDAPB1 {
+    #[allow(unused)]
+    pub(crate) fn enr(&mut self) -> &rcu::ADDEN {
+        // NOTE(unsafe) this proxy grants exclusive access to this register
+        unsafe { &(*RCU::ptr()).adden }
+    }
+
+    #[allow(unused)]
+    pub(crate) fn rstr(&mut self) -> &rcu::ADDRST {
+        // NOTE(unsafe) this proxy grants exclusive access to this register
+        unsafe { &(*RCU::ptr()).addrst }
+    }
+}
+
 /// Frequency of the internal 8MHz RC oscillator in Hz
 const IRC8M: u32 = 8_000_000;
 
@@ -305,6 +335,7 @@ impl CFGR {
             })
         });
 
+        #[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
         // the USB clock is only valid if an external crystal is used, the PLL is enabled, and the
         // PLL output frequency is a supported one.
         // usbpre == false: divide clock by 1.5, otherwise no division
@@ -360,8 +391,6 @@ impl CFGR {
                 .variant(apb1psc)
                 .ahbpsc()
                 .variant(ahbpsc)
-                .usbdpsc()
-                .variant(usbpre)
                 .scs()
                 .variant(if pllmf_bits.is_some() {
                     SCS_A::PLL
@@ -371,6 +400,10 @@ impl CFGR {
                     SCS_A::IRC8M
                 })
         });
+        #[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
+        {
+            rcu.cfg0.modify(|_, w| w.usbdpsc().variant(usbpre));
+        }
         rcu.cfg2.modify(|_, w| w.adcsel().apb2().usart0sel().apb2());
 
         Clocks {
@@ -381,6 +414,7 @@ impl CFGR {
             ppre2,
             sysclk: Hertz(sysclk),
             adcclk: Hertz(adcclk),
+            #[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
             usbclk_valid,
         }
     }
@@ -427,6 +461,7 @@ pub struct Clocks {
     ppre2: u8,
     sysclk: Hertz,
     adcclk: Hertz,
+    #[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
     usbclk_valid: bool,
 }
 
@@ -477,6 +512,7 @@ impl Clocks {
     }
 
     /// Returns whether the USBCLK clock frequency is valid for the USB peripheral
+    #[cfg(any(feature = "gd32f130", feature = "gd32f150"))]
     pub fn usbclk_valid(&self) -> bool {
         self.usbclk_valid
     }
@@ -504,6 +540,15 @@ impl GetBusFreq for APB1 {
     }
 }
 
+impl GetBusFreq for ADDAPB1 {
+    fn get_frequency(clocks: &Clocks) -> Hertz {
+        clocks.pclk1
+    }
+    fn get_timer_frequency(clocks: &Clocks) -> Hertz {
+        clocks.pclk1_tim()
+    }
+}
+
 impl GetBusFreq for APB2 {
     fn get_frequency(clocks: &Clocks) -> Hertz {
         clocks.pclk2
@@ -584,8 +629,6 @@ bus! {
     ADC => (APB2, adcen, adcrst),
     I2C0 => (APB1, i2c0en, i2c0rst),
     I2C1 => (APB1, i2c1en, i2c1rst),
-    // TODO: Support I2C2 on GD32F170/GD32F190
-    //I2C2 => (ADDAPB1, i2c2en, i2c2rst),
     SPI0 => (APB2, spi0en, spi0rst),
     SPI1 => (APB1, spi1en, spi1rst),
     SPI2 => (APB1, spi2en, spi2rst),
@@ -602,7 +645,7 @@ bus! {
     WWDGT => (APB1, wwdgten, wwdgtrst),
 }
 
-#[cfg(feature = "gd31f150")]
+#[cfg(feature = "gd32f150")]
 bus! {
     USBD => (APB1, usbden, usbdrst),
 }
@@ -611,6 +654,7 @@ bus! {
 bus! {
     CAN0 => (APB1, can0en, can0rst),
     CAN1 => (APB1, can1en, can1rst),
+    I2C2 => (ADDAPB1, i2c2en, i2c2rst),
 }
 
 ahb_bus! {
